@@ -20,7 +20,6 @@ local({
     loadNamespace("Rmpi")
     loadNamespace("snow")
 
-    #sinkWorkerOutput(outfile)
-    message("starting MPI worker\n")
     BiocParallel::bprunMPIslave()
+    quit("no")
 })
